#!/bin/bash

# Couleurs pour les messages
GREEN="\033[0;32m"
RED="\033[0;31m"
NC="\033[0m" # No Color

echo -e "${GREEN}--- Audit Docker sur le serveur Linux ---${NC}"

# Vérification si Docker est installé
if ! command -v docker &> /dev/null
then
    echo -e "${RED}Docker n'est pas installé sur ce serveur.${NC}"
    exit 1
fi

# 1. Version de Docker
echo -e "${GREEN}\n1. Version de Docker:${NC}"
docker --version

# 2. Statut du service Docker
echo -e "${GREEN}\n2. Statut du service Docker:${NC}"
if systemctl is-active --quiet docker
then
    echo -e "${GREEN}Docker est actif.${NC}"
else
    echo -e "${RED}Docker n'est pas actif.${NC}"
fi

# 3. Utilisateurs dans le groupe docker
echo -e "${GREEN}\n3. Utilisateurs appartenant au groupe docker:${NC}"
getent group docker | cut -d: -f4

# 4. Conteneurs en cours d'exécution
echo -e "${GREEN}\n4. Conteneurs en cours d'exécution:${NC}"
docker ps --format "table {{.ID}}\t{{.Names}}\t{{.Status}}\t{{.Ports}}"

# 5. Images Docker présentes
echo -e "${GREEN}\n5. Images Docker présentes sur le serveur:${NC}"
docker images --format "table {{.Repository}}\t{{.Tag}}\t{{.Size}}"

# 6. Volumes Docker
echo -e "${GREEN}\n6. Volumes Docker disponibles:${NC}"
docker volume ls --format "table {{.Name}}"

# 7. Ports exposés
echo -e "${GREEN}\n7. Ports exposés par les conteneurs en cours:${NC}"
docker ps --format "table {{.ID}}\t{{.Names}}\t{{.Ports}}"

# 8. Fichier de configuration de Docker Daemon
echo -e "${GREEN}\n8. Vérification du fichier de configuration /etc/docker/daemon.json:${NC}"
if [ -f /etc/docker/daemon.json ]; then
    cat /etc/docker/daemon.json
else
    echo -e "${RED}Le fichier /etc/docker/daemon.json n'existe pas.${NC}"
fi

# Audit terminé
echo -e "${GREEN}\n--- Audit terminé ---${NC}"
